"""
Captcha solver to SEACE Portal Scraper
The model have a 92% Accuracy.
"""
import pkg_resources
pkg_resources.declare_namespace(__name__)
#from gimpysolver import captcha_solver

__version__ = "0.0.8"
__author__ = 'César Cortez'
__credits__ = 'Digitalia Tec'